@@ -68,14 +68,23 @@ def make_incompatible_merge_headers_error(error_modal: bool=True) -> MitoError:
         error_modal=error_modal
     )
 
-def make_incompatible_merge_key_error(error_modal: bool=True) -> MitoError:
+def make_incompatible_merge_key_error(merge_key_one: Optional[ColumnHeader]=None, merge_key_one_dtype: Optional[str]=None, merge_key_two: Optional[ColumnHeader]=None, merge_key_two_dtype: Optional[str]=None, error_modal: bool=True) -> MitoError:
     """
     Helper function for creating a incompatible_merge_key_error
 
     Occurs when a user merges on two keys that are different types
     """
-    to_fix = f'You cannot merge using keys of different types. Either pick new keys or cast their types.'
+    from mitosheet.column_headers import get_column_header_display
 
+    if merge_key_one is not None and merge_key_two is not None:
+        return MitoError(
+            'incompatible_merge_key_error', 
+            'Incompatible Merge Key Types',
+            f'{get_column_header_display(merge_key_one)} ({merge_key_one_dtype}) and {get_column_header_display(merge_key_two)} ({merge_key_two_dtype}) have different types. Either pick new keys or cast their types.',
+            error_modal=error_modal
+        )
+    
+    to_fix = f'You cannot merge using keys of different types. Either pick new keys or cast their types.'
     return MitoError(
         'incompatible_merge_key_error', 
         'Incompatible Merge Key Types',
@@ -131,6 +140,22 @@ def make_invalid_formula_error(formula: str, to_fix: str=None, error_modal: bool
         error_modal=error_modal
     )
 
+def make_invalid_formula_after_update_error(error_modal: bool=False) -> MitoError:
+    """
+    Helper function for creating a invalid_formula_after_update_error.
+
+    Occurs when a user edits a user tries to resubmit a formula that used to be
+    valid and is no longer valid - which must mean they changed something they 
+    rely on.
+    """
+  
+    return MitoError(
+        'invalid_formula_after_update_error', 
+        'Formula is Now Invalid',
+        'Renaming or deleting other columns in this dataset has made this formula invalid. Please update this formula.',
+        error_modal=error_modal
+    )
+
 
 def make_cast_value_to_type_error(value: str, column_dtype: str, error_modal: bool=True) -> MitoError:
     """
@@ -421,6 +446,21 @@ def make_invalid_promote_row_to_header(error_modal: bool=True) -> MitoError:
         error_modal=error_modal
     )
 
+def make_invalid_simple_import_error(error_modal: bool=False) -> MitoError:
+    """
+    Helper function for creating a invalid_simple_import_error.
+
+    Occurs when a user tries to simple import and it fails
+    """
+    to_fix = f'We were unable to automatically determine a delimeter and encoding. Please select a delemeter and encoding.' 
+    
+    return MitoError(
+        'invalid_simple_import_error', 
+        "Cannot Determine File Data",
+        to_fix,
+        error_modal=error_modal
+    )
+
 ARG_FULL_NAME = {
     'int': 'number',
     'float': 'number',
