@@ -124,10 +124,8 @@ class FilterStepPerformer(StepPerformer):
         ]
 
     @classmethod
-    def get_modified_dataframe_indexes(  # type: ignore
-        cls, sheet_index: int, column_id: ColumnID, operator: str, filters, **params
-    ) -> Set[int]:
-        return {sheet_index}
+    def get_modified_dataframe_indexes(cls, params: Dict[str, Any]) -> Set[int]:
+        return {get_param(params, 'sheet_index')}
 
 
 def get_applied_filter(
